/***************************************************************************
 *
 * $Id: acconfig.h,v 1.6.4.2 2004/05/06 08:57:52 bazsi Exp $
 *
 * Copyright (c) 1999 BalaBit Computing
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * Inspired by nsyslog, originally written by Darren Reed.
 *
 ***************************************************************************/

#define PACKAGE "configure-generated"
#define VERSION "configure-generated"

#define YYDEBUG 1

#define WITH_DEBUG      0

#define HAVE_MODERN_UTMP  0

#define HAVE_SUN_STREAMS 0

#define HAVE_SUN_DOOR 0

#undef HAVE_O_LARGEFILE 

#undef PATH_SYSCONFDIR 

#undef ENABLE_TCP_WRAPPER

#undef HAVE_RES_INIT

#undef ENABLE_SPOOF_SOURCE 

#undef HAVE_GLOBAL_TIMEZONE
